##  Managing Presentations in Bulk
To manage presentations in bulk, switch to the list view by clicking the hamburger menu icon in the upper-right corner of the presentations page.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio012aad86b46743e7b8fca450f1508e64_LowRes.png)
Switching Between the List and Grid Views in Presentations
In the list view, you can share presentations in bulk. If you have sufficient permissions, you can also change ownership or delete presentations in bulk.
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio5447a9d9c47347e9a1c03171e6071b4d_LowRes.png)
Managing Presentations in Bulk from the List View
Presentation permissions depend on your user role and ownership. Admin users can access all presentations and can grant full permissions for presentations to non-admin roles. The presentation owner always has editing permissions. For more information, see [Presentation Permissions](https://help.sap.com/docs/leanix/ea/presentations?locale=en-US&state=PRODUCTION&version=CLOUD#loio275be6437a4410148a0a96eb313dc8f8__presentation_permissions).
